@@ -14,18 +14,19 @@ from pyalarmdotcomajax.helpers import slug_to_title
 
 from . import const as c
 from .devices import BaseDevice
-from .devices import Camera
 from .devices import DEVICE_URLS
 from .devices import DeviceType
 from .devices import ElementSpecificData
-from .devices import GarageDoor
-from .devices import ImageSensor
-from .devices import Light
-from .devices import Lock
-from .devices import Partition
-from .devices import Sensor
-from .devices import System
 from .devices import TroubleCondition
+from .devices.camera import Camera
+from .devices.garage_door import GarageDoor
+from .devices.image_sensor import ImageSensor
+from .devices.light import Light
+from .devices.lock import Lock
+from .devices.partition import Partition
+from .devices.sensor import Sensor
+from .devices.system import System
+from .devices.thermostat import Thermostat
 from .errors import AuthenticationFailed
 from .errors import BadAccount
 from .errors import DataFetchFailed
@@ -36,11 +37,12 @@ from .extensions import CameraSkybellControllerExtension
 from .extensions import ConfigurationOption
 from .extensions import ExtendedProperties
 
-__version__ = "0.3.2"
+__version__ = "0.4"
 
 
 log = logging.getLogger(__name__)
 
+# Map DeviceType enum to device class.
 DEVICE_CLASSES: dict = {
     DeviceType.CAMERA: Camera,
     DeviceType.GARAGE_DOOR: GarageDoor,
@@ -50,6 +52,7 @@ DEVICE_CLASSES: dict = {
     DeviceType.PARTITION: Partition,
     DeviceType.SENSOR: Sensor,
     DeviceType.SYSTEM: System,
+    DeviceType.THERMOSTAT: Thermostat,
 }
 
 
@@ -149,6 +152,7 @@ class AlarmController:
         self.image_sensors: list[ImageSensor] = []
         self.lights: list[Light] = []
         self.cameras: list[Camera] = []
+        self.thermostats: list[Thermostat] = []
 
     #
     #
@@ -225,7 +229,6 @@ class AlarmController:
         """Request SMS/email OTP code from Alarm.com."""
 
         try:
-
             log.debug("Requesting OTP code...")
 
             request_url = (
@@ -258,7 +261,6 @@ class AlarmController:
 
         # Submit code
         try:
-
             log.debug("Submitting OTP code...")
 
             if not self._two_factor_method:
@@ -269,7 +271,7 @@ class AlarmController:
                 headers=self._ajax_headers,
                 json={"code": code, "typeOf2FA": self._two_factor_method.value},
             ) as resp:
-                json_rsp = await (resp.json())
+                json_rsp = await resp.json()
 
         except (asyncio.TimeoutError, aiohttp.ClientError) as err:
             log.error("Can not load 2FA submission page from Alarm.com")
@@ -294,7 +296,6 @@ class AlarmController:
         # Submit device name for "remember me" function.
         if json_rsp.get("value", {}).get("deviceName"):
             try:
-
                 log.debug("Registering device...")
 
                 async with self._websession.post(
@@ -304,7 +305,7 @@ class AlarmController:
                     headers=self._ajax_headers,
                     json={"deviceName": device_name},
                 ) as resp:
-                    json_rsp = await (resp.json())
+                    json_rsp = await resp.json()
             except (asyncio.TimeoutError, aiohttp.ClientError) as err:
                 log.error("Can not load device trust page from Alarm.com")
                 raise DataFetchFailed from err
@@ -329,7 +330,6 @@ class AlarmController:
         log.debug("Calling update on Alarm.com")
 
         try:
-
             await self._async_get_trouble_conditions()
 
             device_types: list[DeviceType] = (
@@ -350,7 +350,8 @@ class AlarmController:
         | Partition.Command
         | GarageDoor.Command
         | Light.Command
-        | ImageSensor.Command,
+        | ImageSensor.Command
+        | Thermostat.Command,
         device_id: str | None = None,  # ID corresponds to device_type
         msg_body: dict | None = None,  # Body of request. No abstractions here.
         retry_on_failure: bool = True,  # Set to prevent infinite loops when function calls itself
@@ -371,7 +372,6 @@ class AlarmController:
         async with self._websession.post(
             url=url, json=msg_body, headers=self._ajax_headers
         ) as resp:
-
             log.debug("Response from Alarm.com %s", resp.status)
             if resp.status == 200:
                 # Update alarm.com status after calling state change.
@@ -433,16 +433,7 @@ class AlarmController:
 
     async def async_get_raw_server_responses(
         self,
-        device_types: list[
-            type[System]
-            | type[Partition]
-            | type[Sensor]
-            | type[Lock]
-            | type[GarageDoor]
-            | type[ImageSensor]
-            | type[Light]
-            | type[Camera]
-        ],
+        device_types: list[type[BaseDevice]],
         include_image_sensor_b64: bool = False,
     ) -> dict:
         """Get raw responses from Alarm.com device endpoints."""
@@ -463,13 +454,12 @@ class AlarmController:
             endpoints.append(("Image Sensor Data", c.IMAGE_SENSOR_DATA_URL_TEMPLATE))
 
         for name, url_template in endpoints:
-
             async with self._websession.get(
                 url=url_template.format(c.URL_BASE, ""),
                 headers=self._ajax_headers,
             ) as resp:
                 try:
-                    json_rsp = await (resp.json())
+                    json_rsp = await resp.json()
 
                     if name == "Image Sensor Data" and not include_image_sensor_b64:
                         for image in json_rsp["data"]:
@@ -478,7 +468,6 @@ class AlarmController:
                     rsp_errors = json_rsp.get("errors", [])
 
                     if len(rsp_errors) != 0:
-
                         error_msg = (
                             "async_get_raw_server_responses(): Failed to get data."
                             f" Response: {rsp_errors}"
@@ -513,12 +502,10 @@ class AlarmController:
 
         return return_data
 
-    def get_device_by_id(
-        self, device_id: str
-    ) -> BaseDevice | System | Partition | Sensor | Lock | GarageDoor | ImageSensor | Light | Camera | None:
+    def get_device_by_id(self, device_id: str) -> BaseDevice | None:
         """Find device by its id."""
 
-        device: BaseDevice | System | Partition | Sensor | Lock | GarageDoor | ImageSensor | Light | Camera
+        device: BaseDevice
         for device in (
             *self.systems,
             *self.partitions,
@@ -528,6 +515,7 @@ class AlarmController:
             *self.image_sensors,
             *self.lights,
             *self.cameras,
+            *self.thermostats,
         ):
             if device.id_ == device_id:
                 return device
@@ -549,21 +537,11 @@ class AlarmController:
         """Get data for the specified device types and build objects."""
 
         for device_type in device_types:
-
             #
             # DETERMINE DEVICE'S PYALARMDOTCOMAJAX PYTHON CLASS
             #
             try:
-                device_class: (
-                    type[GarageDoor]
-                    | type[Lock]
-                    | type[Sensor]
-                    | type[ImageSensor]
-                    | type[Light]
-                    | type[Partition]
-                    | type[System]
-                    | type[Camera]
-                ) = DEVICE_CLASSES[device_type]
+                device_class: (type[BaseDevice]) = DEVICE_CLASSES[device_type]
 
             except KeyError as err:
                 raise UnsupportedDevice from err
@@ -610,7 +588,6 @@ class AlarmController:
             additional_endpoint_raw_results: dict = {}
 
             try:
-
                 additional_endpoints: dict = DEVICE_URLS["supported"][device_type][
                     "additional_endpoints"
                 ]
@@ -621,7 +598,6 @@ class AlarmController:
                     ] = await self._async_get_items_and_subordinates(url=url)
 
             except KeyError:
-
                 pass
 
             ####################
@@ -665,16 +641,18 @@ class AlarmController:
             extension_controller: CameraSkybellControllerExtension | None = None
 
             for extension_class in required_extensions:
-
                 extension_controller = extension_class(
                     websession=self._websession,
                     headers=self._ajax_headers,
                 )
 
-                # Fetch from Alarm.com
-                extended_properties_list: list[
-                    ExtendedProperties
-                ] = await extension_controller.fetch()
+                try:
+                    # Fetch from Alarm.com
+                    extended_properties_list: list[
+                        ExtendedProperties
+                    ] = await extension_controller.fetch()
+                except UnexpectedDataStructure:
+                    continue
 
                 # Match extended properties to devices by name, then add to device_settings storage.
                 for extended_property in extended_properties_list:
@@ -703,7 +681,6 @@ class AlarmController:
                             .get("id")
                         )
                     ):
-
                         element_specific_data.setdefault(
                             image_sensor_id, {}
                         ).setdefault("raw_recent_images", set()).add(image)
@@ -715,7 +692,6 @@ class AlarmController:
             temp_device_storage: list = []
 
             for device_raw_attribs, subordinates in devices:
-
                 entity_id = device_raw_attribs["id"]
 
                 entity_obj = device_class(
@@ -750,6 +726,8 @@ class AlarmController:
                 self.image_sensors[:] = temp_device_storage
             elif device_class is Camera:
                 self.cameras[:] = temp_device_storage
+            elif device_class is Thermostat:
+                self.thermostats[:] = temp_device_storage
 
     #
     #
@@ -767,7 +745,7 @@ class AlarmController:
             ),
             headers=self._ajax_headers,
         ) as resp:
-            json_rsp = await (resp.json())
+            json_rsp = await resp.json()
 
         if (errors := json_rsp.get("errors")) and len(errors) > 0:
             for error in errors:
@@ -782,7 +760,7 @@ class AlarmController:
                         ),
                         headers=self._ajax_headers,
                     ) as resp:
-                        json_rsp = await (resp.json())
+                        json_rsp = await resp.json()
 
                         if isinstance(
                             factor_id := json_rsp.get("data", {}).get("id"), int
@@ -809,7 +787,7 @@ class AlarmController:
                 headers=self._ajax_headers,
                 cookies=self._two_factor_cookie,
             ) as resp:
-                json_rsp = await (resp.json())
+                json_rsp = await resp.json()
 
                 log.debug("Got identity info:\n%s", json.dumps(json_rsp))
 
@@ -841,7 +819,7 @@ class AlarmController:
                 url=c.TROUBLECONDITIONS_URL_TEMPLATE.format(c.URL_BASE, ""),
                 headers=self._ajax_headers,
             ) as resp:
-                json_rsp = await (resp.json())
+                json_rsp = await resp.json()
 
                 log.debug("Got trouble conditions:\n%s", json_rsp)
 
@@ -901,7 +879,7 @@ class AlarmController:
             url=full_path.format(c.URL_BASE, ""),
             headers=self._ajax_headers,
         ) as resp:
-            json_rsp = await (resp.json())
+            json_rsp = await resp.json()
 
         return_items = []
 
@@ -911,7 +889,6 @@ class AlarmController:
 
         rsp_errors = json_rsp.get("errors", [])
         if len(rsp_errors) != 0:
-
             error_msg = (
                 "_async_get_items_and_subordinates(): Failed to get data for device"
                 f" type {device_type}. Response: {rsp_errors}. Errors: {json_rsp}."
@@ -983,12 +960,9 @@ class AlarmController:
                         DeviceType.SYSTEM,
                     ]:
                         for family_name, family_data in device["relationships"].items():
-
                             # TODO: Get list of unsupported devices to notify user of what has not been collected. Currently only collects known unknowns.
                             if DeviceType.has_value(family_name):
-
                                 for sub_device in family_data["data"]:
-
                                     subordinates.append(
                                         (sub_device["id"], sub_device["type"])
                                     )
@@ -1061,7 +1035,6 @@ class AlarmController:
                 },
                 cookies=self._two_factor_cookie,
             ) as resp:
-
                 if re.search("m=login_fail", str(resp.url)) is not None:
                     log.error("Login failed.")
                     log.error("\nResponse URL:\n%s\n", str(resp.url))
